
# q-expansion of newform 700.6.e.h, downloaded from the LMFDB on 02 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 700
weight = 6
poly_data = [3027600, 0, 100824, 0, 625, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0], 1], [[1740, 0, 313, 0, 1, 0], 1428], [[0, 443796, 0, 1115, 0, -1], 2484720], [[44784, 0, 517, 0, 1, 0], 204], [[0, 79275516, 0, 779885, 0, 1529], 2484720]]

hecke_ring_character_values = [[351, [1, 0, 0, 0, 0, 0]], [477, [-1, 0, 0, 0, 0, 0]], [101, [1, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0], [0, 1, 0, 3, 0, 0], [0, 0, 0, 0, 0, 0], [0, 0, 0, -49, 0, 0], [26, 0, 19, 0, -1, 0], [0, 25, 0, -55, 0, -8], [0, -55, 0, 477, 0, -16], [-591, 0, -96, 0, -15, 0], [0, -32, 0, -1399, 0, 25], [-1858, 0, -25, 0, -23, 0], [871, 0, -178, 0, 25, 0], [0, 90, 0, 5021, 0, 57], [2587, 0, -16, 0, -71, 0], [0, -284, 0, -8225, 0, 55], [0, 883, 0, 6793, 0, 88], [0, 654, 0, -250, 0, -246], [-5032, 0, -2208, 0, 0, 0], [-1455, 0, 896, 0, -353, 0], [0, 3144, 0, 10692, 0, -24], [-7584, 0, -2840, 0, 392, 0], [0, 3604, 0, 18960, 0, 22], [-20776, 0, -1053, 0, 153, 0], [0, -2520, 0, 4474, 0, 762], [48457, 0, 392, 0, -101, 0], [0, 7965, 0, 2873, 0, 720], [-137229, 0, 1842, 0, 15, 0], [0, 4513, 0, -5, 0, -1256], [0, -4778, 0, 63302, 0, 424], [31044, 0, 4245, 0, 1689, 0], [0, -5870, 0, 31293, 0, 601], [0, 816, 0, 101512, 0, -864], [-175505, 0, 272, 0, -305, 0], [0, -4536, 0, 61671, 0, 741], [-217412, 0, -5050, 0, -914, 0], [-121596, 0, 8328, 0, -1038, 0], [-50790, 0, -9551, 0, 1925, 0], [0, -5116, 0, 49718, 0, 464], [0, 1154, 0, -473488, 0, -202], [0, 3375, 0, 493461, 0, -1704], [0, -25229, 0, 135573, 0, -1754], [-163724, 0, 3328, 0, -424, 0], [-75726, 0, -12646, 0, -1634, 0], [255438, 0, -39081, 0, 1275, 0], [0, -10048, 0, 33173, 0, 3623], [0, -31608, 0, 347627, 0, 3525], [-305406, 0, 39332, 0, -2402, 0], [43580, 0, 31129, 0, -7501, 0], [0, 25349, 0, -568455, 0, 170], [0, 20823, 0, 15467, 0, 3774], [94309, 0, -26392, 0, -4913, 0], [0, 12366, 0, -594882, 0, -594], [53682, 0, 4819, 0, -4933, 0], [-1027157, 0, -13998, 0, 6471, 0], [-670280, 0, -17138, 0, 11090, 0], [0, 81568, 0, -422492, 0, -13382], [0, 23890, 0, 809580, 0, 1342], [718312, 0, 54916, 0, 14750, 0], [-621805, 0, -44350, 0, -5975, 0], [0, -28028, 0, -63340, 0, 2314], [-554626, 0, 48537, 0, 1647, 0], [0, 69047, 0, 205199, 0, -9430], [0, -76993, 0, 270573, 0, -7078], [0, -14335, 0, 1331765, 0, -6022], [-1316769, 0, -30816, 0, -12729, 0], [0, -67343, 0, -194313, 0, 6526], [0, 25804, 0, 845700, 0, 9946], [2164328, 0, 46432, 0, 11060, 0], [0, -6836, 0, 2314290, 0, 1948], [0, 60332, 0, -431455, 0, -12775], [-1810821, 0, -34322, 0, -12529, 0], [0, 138303, 0, 225129, 0, -14826], [-396568, 0, -114008, 0, 10184, 0], [0, -8781, 0, -717779, 0, -24204], [0, 38512, 0, -2225913, 0, 19429], [-480824, 0, 168832, 0, -6388, 0], [0, 54248, 0, 1331854, 0, -14098], [134924, 0, 129193, 0, -18043, 0], [0, 133145, 0, -489787, 0, 3920], [3044524, 0, -10653, 0, -16989, 0], [-3464996, 0, 7552, 0, 17150, 0], [1629596, 0, 79916, 0, 1768, 0], [2681782, 0, -32473, 0, 3109, 0], [1080324, 0, -143145, 0, 4137, 0], [0, -264568, 0, -1641646, 0, 4028], [142336, 0, -281734, 0, 43846, 0], [0, 14124, 0, -1760725, 0, -24429], [-1659062, 0, 474019, 0, -5899, 0], [0, -207752, 0, -979323, 0, 12547], [-492330, 0, -301162, 0, 4030, 0], [0, 413610, 0, 782977, 0, 1347], [0, -178507, 0, -4709475, 0, -5530], [3850793, 0, 107768, 0, -43559, 0], [0, 67422, 0, -1810468, 0, 48162], [-792694, 0, -49231, 0, -33791, 0], [2387678, 0, 275489, 0, 14821, 0], [0, -55197, 0, 164667, 0, 36330], [3433522, 0, 54128, 0, -2468, 0], [5928735, 0, 2554, 0, -17701, 0], [0, -374036, 0, -3089396, 0, -13880], [-2186974, 0, -431647, 0, -40217, 0], [0, -31882, 0, -2677127, 0, 28331], [0, 492046, 0, -2233986, 0, -12434], [0, -320116, 0, -3309796, 0, 1208], [-1315758, 0, -447456, 0, 29388, 0], [7151974, 0, -95492, 0, -30346, 0], [0, 793491, 0, -1093499, 0, -57294], [0, 260372, 0, -159858, 0, -44806], [0, -7883, 0, -2011549, 0, 42382], [3326368, 0, -443111, 0, -36373, 0], [-782114, 0, -435716, 0, -33976, 0], [0, -115507, 0, 7201841, 0, -24934], [0, 625708, 0, 5521814, 0, -3512], [0, -56492, 0, 2542648, 0, 107218], [-7701365, 0, 236052, 0, 82095, 0], [1195030, 0, 855131, 0, 1687, 0], [6441822, 0, -7928, 0, 30260, 0], [0, 40297, 0, -5097209, 0, -26132], [0, 242820, 0, -580850, 0, 109458], [0, -206638, 0, 8811773, 0, 17909], [12120720, 0, 307213, 0, 28259, 0], [749124, 0, -539854, 0, 133744, 0], [0, 931056, 0, 3824321, 0, 243], [0, 739867, 0, -5057647, 0, -73106], [0, 399974, 0, -11015803, 0, 79151], [7227882, 0, -189784, 0, -88334, 0], [-5430078, 0, -410803, 0, -42077, 0], [9314668, 0, 324635, 0, -178709, 0], [-5105369, 0, -779444, 0, -58957, 0], [0, 717988, 0, 4253366, 0, 49450], [0, -86555, 0, 11657377, 0, -187484], [4287058, 0, 310013, 0, -185963, 0], [0, 418120, 0, 3429242, 0, -104846], [-6695296, 0, 834165, 0, -115953, 0], [0, -435094, 0, 1775936, 0, -204964], [-3366915, 0, 124398, 0, 31077, 0], [8497634, 0, 966252, 0, -45456, 0], [0, 680265, 0, -9357447, 0, 145512], [0, -750165, 0, -9064595, 0, -115596], [0, -789075, 0, -1220037, 0, 95610], [-5623524, 0, 4485, 0, -140475, 0], [-9775842, 0, -720374, 0, -123004, 0], [-23065098, 0, 418515, 0, 26649, 0], [0, 253862, 0, 401661, 0, 171827], [0, -1387422, 0, 9977624, 0, 177366], [-15128731, 0, -888536, 0, -21361, 0], [11108197, 0, 1164012, 0, 107241, 0], [0, 330764, 0, 32802482, 0, 27728], [0, -1566784, 0, -3638450, 0, 55652], [-7907952, 0, 951036, 0, 110436, 0], [0, 544674, 0, -9911251, 0, -113673], [0, 102246, 0, -19329973, 0, -75093], [-6530678, 0, -1875730, 0, 10450, 0], [0, -1343190, 0, 16138257, 0, 167367], [0, 863856, 0, 14442836, 0, -86124], [0, -633828, 0, 18405287, 0, 104679], [-9853946, 0, -1442492, 0, -256462, 0], [-5722698, 0, -752965, 0, -268361, 0], [-9900768, 0, -571574, 0, -51880, 0], [0, 215153, 0, 1667559, 0, -111982], [6432729, 0, -442040, 0, -328657, 0], [0, -1474094, 0, 3192967, 0, -291995], [0, 462340, 0, -31827619, 0, 135883], [0, 2090358, 0, 3703618, 0, 255984], [10118259, 0, 39090, 0, 260577, 0], [0, 1015302, 0, 35076027, 0, 13815], [0, 685067, 0, -15482905, 0, 49382], [-6861812, 0, -1255056, 0, 359028, 0], [0, 353577, 0, -35657521, 0, 210570]]
